"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const event_manager_1 = __importDefault(require("./event-manager"));
class HooksManager extends event_manager_1.default {
    _hookHandlers;
    constructor() {
        super();
        this._hookHandlers = new Map();
    }
    // Adds a handler function for a specific event
    addHandler(event, handler) {
        const eventHandlers = this._hookHandlers.get(event);
        if (eventHandlers) {
            eventHandlers.push(handler);
        }
        else {
            this._hookHandlers.set(event, [handler]);
        }
    }
    // Removes a specific handler function for a specific event
    removeHandler(event, handler) {
        const eventHandlers = this._hookHandlers.get(event);
        if (eventHandlers) {
            const index = eventHandlers.indexOf(handler);
            if (index !== -1) {
                eventHandlers.splice(index, 1);
            }
        }
    }
    // Triggers all handlers for a specific event with provided data
    trigger(event, data) {
        const eventHandlers = this._hookHandlers.get(event);
        if (eventHandlers) {
            for (const handler of eventHandlers) {
                try {
                    handler(data);
                }
                catch (error) {
                    this.emit('error', new Error(`Error in hook handler for event "${event}": ${error.message}`));
                }
            }
        }
    }
    // Provides read-only access to the current handlers
    get handlers() {
        // Creating a new map to prevent external modifications to the original map
        return new Map(this._hookHandlers);
    }
}
exports.default = HooksManager;
module.exports = HooksManager;
//# sourceMappingURL=hooks-manager.js.map